//+------------------------------------------------------------------+
//|                                                        WPRV2.mq4 |
//|                                       Copyright  2013, tidicofx |
//|                                               tidicofx@yahoo.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2013, tidicofx"
#property link      "tidicofx@yahoo.com"
#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1 Aqua
#property indicator_width1 1
#property indicator_color2 Red
#property indicator_width2 2
#property indicator_minimum -100
#property indicator_maximum 0
//+------------------------------------------------------------------+
#include <stdlib.mqh>
#include <stderror.mqh>
//+------------------------------------------------------------------+
//| Input Parameters Definition                                      |
//+------------------------------------------------------------------+
extern int  WPRPeriod = 14;
extern bool ShowAlert = true;
extern int  Level1 = -20;
extern int  Level2 = -50;
extern int  Level3 = -80;
//+------------------------------------------------------------------+
//| Local Parameters Definition                                      |
//+------------------------------------------------------------------+
string lbl = "WPRV2";
double WPRBuffer[], CurrentBuffer[];
datetime lastAlert1, lastAlert2, lastAlert3;
int last1, last2, last3;
double old;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
  //------------------------------------------------------------------
  SetIndexBuffer(0, WPRBuffer); SetIndexStyle(0, DRAW_LINE); SetIndexLabel(0, "Wpr");
  SetIndexBuffer(1, CurrentBuffer); SetIndexStyle(1, DRAW_LINE); SetIndexLabel(1, "Current");
  SetIndexDrawBegin(0, WPRPeriod);
  IndicatorShortName("WPR("+WPRPeriod+")");
  //------------------------------------------------------------------
  int level = Level1;
  if (Level1 == 0) level = Level2;
  if (Level1 == 0 && Level2 == 0) level = Level3;
  if (Level1 != 0) SetLevelValue(0, Level1); else SetLevelValue(0, level);
  if (Level2 != 0) SetLevelValue(1, Level2); else SetLevelValue(1, level);
  if (Level3 != 0) SetLevelValue(2, Level3); else SetLevelValue(2, level);
  //------------------------------------------------------------------
  lastAlert1 = 0; lastAlert2 = 0; lastAlert3 = 0; old = 0;
  //------------------------------------------------------------------
  return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
  //------------------------------------------------------------------
  //------------------------------------------------------------------
  return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
  //------------------------------------------------------------------
  int counted_bars = IndicatorCounted();
  int limit;
  limit = Bars - counted_bars;
  if (counted_bars > 0) limit--;
  //------------------------------------------------------------------
  for (int i = limit; i >= 0; i--)
  {
    //------------------------------------------------------------------
    WPRBuffer[i] = iWPR(NULL, 0, WPRPeriod, i);
    if (i <= 1) CurrentBuffer[i] = WPRBuffer[i];
    else CurrentBuffer[i] = EMPTY_VALUE;
    if (i >= 1) CurrentBuffer[i+1] = EMPTY_VALUE;
    //------------------------------------------------------------------
  }
  //------------------------------------------------------------------
  if (old == 0) { old = WPRBuffer[0]; return (0); }
  //------------------------------------------------------------------
  if (Level1 != 0)
  {
    if (lastAlert1 != Time[0]) { last1 = -1; lastAlert1 = Time[0]; }
    if (last1 != OP_SELL && NormalizeDouble(old, 4) <= NormalizeDouble(Level1, 4) && NormalizeDouble(WPRBuffer[0], 4) > NormalizeDouble(Level1, 4))
    {
      last1 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level1 + " crossed up (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
    if (last1 != OP_BUY && NormalizeDouble(old, 4) >= NormalizeDouble(Level1, 4) && NormalizeDouble(WPRBuffer[0], 4) < NormalizeDouble(Level1, 4))
    {
      last1 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level1 + " crossed down (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
  }
  //-----------------------------------------------------------------
  if (Level2 != 0)
  {
    if (lastAlert2 != Time[0]) { last2 = -1; lastAlert2 = Time[0]; }
    if (last2 != OP_SELL && NormalizeDouble(old, 4) <= NormalizeDouble(Level2, 4) && NormalizeDouble(WPRBuffer[0], 4) > NormalizeDouble(Level2, 4))
    {
      last2 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level2 + " crossed up (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
    if (last2 != OP_BUY && NormalizeDouble(old, 4) >= NormalizeDouble(Level2, 4) && NormalizeDouble(WPRBuffer[0], 4) < NormalizeDouble(Level2, 4))
    {
      last2 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level2 + " crossed down (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
  }
  //-----------------------------------------------------------------
  if (Level3 != 0)
  {
    if (lastAlert3 != Time[0]) { last3 = -1; lastAlert3 = Time[0]; }
    if (last3 != OP_SELL && NormalizeDouble(old, 4) <= NormalizeDouble(Level3, 4) && NormalizeDouble(WPRBuffer[0], 4) > NormalizeDouble(Level3, 4))
    {
      last3 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level3 + " crossed up (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
    if (last3 != OP_BUY && NormalizeDouble(old, 4) >= NormalizeDouble(Level3, 4) && NormalizeDouble(WPRBuffer[0], 4) < NormalizeDouble(Level3, 4))
    {
      last3 = OP_BUY;
      if (ShowAlert) Alert(TimeToStr(TimeCurrent(), TIME_SECONDS) + " " + Symbol() + "(" + GetTimeFrameName(Period()) + ") " + Level3 + " crossed down (old=" + DoubleToStr(old, 4) + ", new=" + DoubleToStr(WPRBuffer[0], 4) + ")");
    }
  }
  //-----------------------------------------------------------------
  old = WPRBuffer[0];
  //-----------------------------------------------------------------
  return(0);
}
//+------------------------------------------------------------------+
string GetTimeFrameName(int TimeFrame)
{
  switch (TimeFrame)
  {
    case PERIOD_M1: return("M1");
    case PERIOD_M5: return("M5");
    case PERIOD_M15: return("M15");
    case PERIOD_M30: return("M30");
    case PERIOD_H1: return("H1");
    case PERIOD_H4: return("H4");
    case PERIOD_D1: return("D1");
    case PERIOD_W1: return("W1");
    case PERIOD_MN1: return("MN1");
    case 0: return(GetTimeFrameName(Period()));
  }
}
//+------------------------------------------------------------------+

